pub struct ZcosmicWorkspaceImageCaptureSourceManagerV1 { /* private fields */ }Available on crate feature
client only.Expand description
image source manager for outputs
A manager for creating image source objects for wl_output objects.
This interface has no events.
Implementations
Sourceimpl ZcosmicWorkspaceImageCaptureSourceManagerV1
impl ZcosmicWorkspaceImageCaptureSourceManagerV1
Sourcepub fn create_source<U: Send + Sync + 'static, D: Dispatch<ExtImageCaptureSourceV1, U> + 'static>(
&self,
output: &ExtWorkspaceHandleV1,
qh: &QueueHandle<D>,
udata: U,
) -> ExtImageCaptureSourceV1
pub fn create_source<U: Send + Sync + 'static, D: Dispatch<ExtImageCaptureSourceV1, U> + 'static>( &self, output: &ExtWorkspaceHandleV1, qh: &QueueHandle<D>, udata: U, ) -> ExtImageCaptureSourceV1
create source object for output
Creates a source object for a workspaces. Images captured from this source will show the same content as the workspace. Some elements may be omitted, such as cursors and overlays that have been marked as transparent to capturing.